@@ -244,17 +244,18 @@ class Monitor():
             if value is not None:
                 return key, value
 
-    def set_brightness(self, *args, **kwargs) -> Union[int, None]:
+    def set_brightness(self, value: int, no_return: bool = False) -> Union[int, None]:
         '''
         Sets the brightness for this display. See `set_brightness` for the full docs
 
         Args:
-            args (tuple): passed directly to this monitor's brightness method
-            kwargs (dict): passed directly to this monitor's brightness method.
-                The `display` kwarg is always overwritten
+            value (int): the brightness value to set the display to (from 0 to 100)
+            no_return (bool): if true, this function returns `None`
+                Otherwise it returns the result of `Monitor.get_brightness`
 
         Returns:
             int: from 0 to 100
+            None: if `no_return==True`
 
         Example:
             ```python
@@ -265,8 +266,8 @@ class Monitor():
             primary.set_brightness(50)
             ```
         '''
-        kwargs['display'] = self.get_identifier()[1]
-        b = self.method.set_brightness(*args, **kwargs)
+        value = max(0, min(value, 100))
+        b = self.method.set_brightness(value, display=self.get_identifier()[1], no_return=no_return)
         if b is not None:
             return b[0]
         return b
@@ -727,7 +728,14 @@ def fade_brightness(
 
     for i in available_monitors:
         try:
-            if platform.system() == 'Linux' and ('method' in kwargs and kwargs['method'].lower() == 'xbacklight'):
+            if (
+                platform.system() == 'Linux'
+                and (
+                    'method' in kwargs
+                    and kwargs['method'] is not None
+                    and kwargs['method'].lower() == 'xbacklight'
+                )
+            ):
                 monitor = i
             else:
                 monitor = Monitor(i)
@@ -747,10 +755,9 @@ def fade_brightness(
             fi = min(max(int(fi), 0), 100)
             st = min(max(int(st), 0), 100)
 
-            if finish != start:
-                t1 = threading.Thread(target=fade, args=(st, fi, increment, monitor))
-                t1.start()
-                threads.append(t1)
+            t1 = threading.Thread(target=fade, args=(st, fi, increment, monitor))
+            t1.start()
+            threads.append(t1)
         except Exception:
             pass
 
@@ -814,5 +821,5 @@ else:
     raise NotImplementedError(f'{plat} is not yet supported')
 del(plat)
 
-__version__ = '0.8.1'
+__version__ = '0.8.2'
 __author__ = 'Crozzers'
